@@ -185,7 +185,11 @@ class Preprocessing(object):
         if "golden_features" in self._params:
             results_path = self._params["golden_features"]["results_path"]
             ml_task = self._params["golden_features"]["ml_task"]
-            self._golden_features = GoldenFeaturesTransformer(results_path, ml_task)
+            features_count = self._params["golden_features"].get("features_count")
+            n_jobs = self._params["golden_features"].get("n_jobs", -1)
+            self._golden_features = GoldenFeaturesTransformer(
+                results_path, ml_task, features_count, n_jobs
+            )
             self._golden_features.fit(X_train[numeric_cols], y_train)
             X_train = self._golden_features.transform(X_train)
             golden_columns = self._golden_features._new_columns
@@ -434,9 +438,7 @@ class Preprocessing(object):
 
     def inverse_categorical_target(self, y):
         if self._categorical_y is not None:
-            y = self._categorical_y.inverse_transform(
-                pd.DataFrame({"target": np.array(y)})
-            )
+            y = self._categorical_y.inverse_transform(y)
             y = y.astype(str)
         return y
 
