@@ -33,7 +33,7 @@ class RandomForestObjective:
         self.y_validation = y_validation
         self.eval_metric = eval_metric
         self.n_jobs = n_jobs
-        self.objective = "mse" if ml_task == REGRESSION else "gini"
+        self.objective = "squared_error" if ml_task == REGRESSION else "gini"
         self.max_steps = 10  # RF is trained in steps 100 trees each
         self.seed = random_state
 
@@ -45,7 +45,7 @@ class RandomForestObjective:
                 else RandomForestAlgorithm
             )
             self.objective = (
-                "mse"
+                "squared_error"
                 if self.ml_task == REGRESSION
                 else trial.suggest_categorical("criterion", ["gini", "entropy"])
             )
